﻿using System;
using Wisej.Core;
using Wisej.Web;
using System.ComponentModel;
using System.Drawing;
using System.Drawing.Design;

namespace Wisej.PropertyGridSample
{
	public class DateEditor : UITypeEditor
	{
		public override UITypeEditorEditStyle GetEditStyle(ITypeDescriptorContext context)
		{
			return UITypeEditorEditStyle.DropDown;
		}

		public override bool GetPaintValueSupported(ITypeDescriptorContext context)
		{
			return true;
		}

		public override object EditValue(ITypeDescriptorContext context, IServiceProvider provider, object value)
		{
			if (provider != null)
			{
				var service = (IWisejEditorService)provider.GetService(typeof(IWisejEditorService));
				if (service != null)
				{
					var dateTime = (DateTime)value;
					if (dateTime == DateTime.MinValue)
						dateTime = DateTime.Now;

					var monthCalendar = new MonthCalendar() {
						MaxSelectionCount = 1,
						SelectionStart = dateTime,
						Size = new Size(250, 250)
					};
					monthCalendar.DateSelected += (s, e) => {
						value = monthCalendar.SelectionStart;
						service.CloseDropDown();
					};

					service.DropDownControl(monthCalendar);
				}
			}
			return value;
		}

		public override void PaintValue(PaintValueEventArgs e)
		{
			e.Graphics.DrawImage(calendar, e.Bounds);
		}

		private static Image calendar = Image.FromFile(Application.MapPath("Resources\\Calendar.png"));
	}
}